@@ -435,18 +435,62 @@ def publish_command() -> None:
         "source_repository_access": agent_config.get(
             "source_repository_access", "private"
         ),
+        # New discovery & classification fields
+        "context": agent_config.get("context"),
+        "primary_function": agent_config.get("primary_function"),
+        "readiness_level": agent_config.get("readiness_level"),
+        # New compatibility requirements
+        "model_requirements": agent_config.get("model_requirements", []),
+        "required_integrations": agent_config.get("required_integrations", []),
+        "required_egress": agent_config.get("required_egress", []),
+        "input_types": agent_config.get("input_types", []),
+        "output_types": agent_config.get("output_types", []),
+        "input_schema": agent_config.get("input_schema", {}),
+        # Flexible metadata
+        "facets": agent_config.get("facets", {}),
     }
 
+    # Validate listing requirements
+    if payload.get("listing_status") == "listed":
+        if payload.get("image_repository_access") != "public":
+            console.print("\n[red]✗[/red] Validation Error:")
+            console.print("  Listed agents must have public image repository access.")
+            console.print(
+                "  Set image_repository_access: 'public' in agent.yaml to list this agent."
+            )
+            console.print(
+                "\n  Note: The AgentSystems public index requires all listed agents to be"
+            )
+            console.print(
+                "  immediately installable. Private images can only be published as unlisted."
+            )
+            raise typer.Exit(1)
+
     # Show what will be published
     console.print("\n[cyan]Publishing agent with the following settings:[/cyan]")
     console.print(f"  Developer: {authenticated_developer}")
     console.print(f"  Name: {name}")
     console.print(f"  Description: {payload.get('description') or '(empty)'}")
+    console.print(f"  Context: {payload.get('context') or '(not set)'}")
+    console.print(
+        f"  Primary Function: {payload.get('primary_function') or '(not set)'}"
+    )
+    console.print(f"  Readiness: {payload.get('readiness_level') or '(not set)'}")
     console.print(f"  Image URL: {payload.get('image_repository_url') or '(empty)'}")
     console.print(f"  Source URL: {payload.get('source_repository_url') or '(empty)'}")
     console.print(f"  Listing: {payload.get('listing_status')}")
     console.print(f"  Image Access: {payload.get('image_repository_access')}")
     console.print(f"  Source Access: {payload.get('source_repository_access')}")
+    if payload.get("model_requirements"):
+        console.print(
+            f"  Model Requirements: {len(payload['model_requirements'])} provider(s)"
+        )
+    if payload.get("required_integrations"):
+        console.print(
+            f"  Required Integrations: {len(payload['required_integrations'])} integration(s)"
+        )
+    if payload.get("input_schema"):
+        console.print(f"  Input Schema: {len(payload['input_schema'])} field(s)")
     console.print()
 
     # Ask for confirmation
@@ -478,26 +522,82 @@ def publish_command() -> None:
                 current_response.raise_for_status()
                 current_agent = current_response.json()
 
-                # Compare settings that will be overwritten
+                # Compare all payload fields against current agent
+                # Skip metadata fields that shouldn't trigger change detection
+                fields_to_ignore = {
+                    "name",  # Name is immutable
+                    "id",
+                    "developer_id",
+                    "created_at",
+                    "updated_at",
+                }
+
+                # Human-friendly labels for fields
+                field_labels = {
+                    "description": "Description",
+                    "image_repository_url": "Image URL",
+                    "source_repository_url": "Source URL",
+                    "listing_status": "Listing Status",
+                    "image_repository_access": "Image Access",
+                    "source_repository_access": "Source Access",
+                    "context": "Context",
+                    "primary_function": "Primary Function",
+                    "readiness_level": "Readiness Level",
+                    "model_requirements": "Model Requirements",
+                    "required_integrations": "Required Integrations",
+                    "required_egress": "Required Egress",
+                    "input_types": "Input Types",
+                    "output_types": "Output Types",
+                    "input_schema": "Input Schema",
+                    "facets": "Facets",
+                }
+
                 changes = []
-                fields_to_check = [
-                    ("description", "Description"),
-                    ("image_repository_url", "Image URL"),
-                    ("source_repository_url", "Source URL"),
-                    ("listing_status", "Listing Status"),
-                    ("image_repository_access", "Image Access"),
-                    ("source_repository_access", "Source Access"),
-                ]
+                for field, new_value in payload.items():
+                    if field in fields_to_ignore:
+                        continue
 
-                for field, label in fields_to_check:
                     current_value = current_agent.get(field)
-                    new_value = payload.get(field)
+
+                    # Deep comparison for lists and dicts
                     if current_value != new_value:
+                        # Format lists and dicts nicely for display
+                        if isinstance(current_value, list):
+                            current_display = (
+                                ", ".join(str(v) for v in current_value)
+                                if current_value
+                                else "(empty)"
+                            )
+                        elif isinstance(current_value, dict):
+                            current_display = (
+                                f"{len(current_value)} item(s)"
+                                if current_value
+                                else "(empty)"
+                            )
+                        else:
+                            current_display = current_value or "(empty)"
+
+                        if isinstance(new_value, list):
+                            new_display = (
+                                ", ".join(str(v) for v in new_value)
+                                if new_value
+                                else "(empty)"
+                            )
+                        elif isinstance(new_value, dict):
+                            new_display = (
+                                f"{len(new_value)} item(s)" if new_value else "(empty)"
+                            )
+                        else:
+                            new_display = new_value or "(empty)"
+
+                        # Use friendly label if available, otherwise use field name with title case
+                        label = field_labels.get(field, field.replace("_", " ").title())
+
                         changes.append(
                             {
                                 "label": label,
-                                "current": current_value or "(empty)",
-                                "new": new_value or "(empty)",
+                                "current": current_display,
+                                "new": new_display,
                             }
                         )
 
